@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Parse the UCI Bach choral harmony data set
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0402';
 
 use Moo;
 use strictures 2;
@@ -343,7 +343,7 @@ Music::BachChoralHarmony - Parse the UCI Bach choral harmony data set
 
 =head1 VERSION
 
-version 0.0401
+version 0.0402
 
 =head1 SYNOPSIS
 
@@ -354,6 +354,7 @@ version 0.0401
 
   # show all the song ids:
   print Dumper [ sort keys %$songs ];
+  print Dumper [ sort keys %{ $bach->data } ]; # Same
 
   # show all the song titles:
   print Dumper [ map { $songs->{$_}{title} } sort keys %$songs ];
@@ -374,10 +375,11 @@ version 0.0401
   $songs = $bach->search( key => 'C_M C_m', chord => 'X_m & F_M' );
 
   # Possibly handy:
-  my $notes = $bach->bits2notes('100000000000');     # C
-  $notes = $bach->bits2notes('010000000000');        # Db
-  $notes = $bach->bits2notes( '010000000000', '#' ); # C#
-  $notes = $bach->bits2notes( '100000000010', '#' ); # C A#
+  my $notes = $bach->bits2notes('100000000000');     # [ C ]
+  $notes = $bach->bits2notes('010000000000');        # [ Db ]
+  $notes = $bach->bits2notes('000000000010');        # [ Bb ]
+  $notes = $bach->bits2notes( '000000000010', '#' ); # [ A# ]
+  $notes = $bach->bits2notes('110000000010');        # [ C Db Bb ]
 
 =head1 DESCRIPTION
 
@@ -386,13 +388,14 @@ chorales.
 
 This module does a few simple things:
 
-1. It turns the UCI CSV data into a perl data structure.
+* It turns the UCI CSV data into a perl data structure.
 
-2. It converts the UCI YES/NO note specification into a bit string.
+* It combines the Bach BWV number, song title and key with the data.
 
-3. It combines the Bach BWV number, song title and key with the data.
+* It converts the UCI YES/NO note specification into a bit string and
+named note list.
 
-4. It allows searching by ids, keys, notes, and chords.
+* It allows searching by ids, keys, notes, and chords.
 
 The BWV and titles were collected from an Internet Archive and
 filled-in from L<https://bach-chorales.com/>.  The keys were computed
@@ -463,16 +466,14 @@ The B<bass>, B<chord>, and B<notes> can be searched either as C<or>
 
 =head2 bits2notes
 
-  $bach->bits2notes($string);
-  $bach->bits2notes( $string, $accidental );
+  $notes = $bach->bits2notes($string);
+  $notes = $bach->bits2notes( $string, $accidental );
 
 Convert a bit-string of 12 binary positions to a note list array
 reference.
 
-The B<accidental> can be given as C<#> sharp or C<b> flat the case of
-enharmonic notes.
-
-Default: C<b>
+The B<accidental> can be given as C<#> sharp or C<b> flat in the case
+of enharmonic notes.  Default: C<b>
 
 The dataset B<notes> bit-string is defined by position as follows:
 
